@@ -1,6 +1,8 @@
 import datetime
 import decimal
 import json
+
+import pytz
 import redis
 from copy import deepcopy
 from typing import Callable
@@ -8,6 +10,7 @@ from django.db import models as django_models
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
 
+
 class RedisField:
 
     def __init__(self, default=None, choices=None, null=True):
@@ -50,7 +53,8 @@ class RedisField:
         if value == 'null':
             if not self.null:
                 if redis_root.ignore_deserialization_errors:
-                    print(f'{datetime.datetime.now()} - {value} can not be deserialized like {self.__class__.__name__}, ignoring')
+                    print(
+                        f'{datetime.datetime.now()} - {value} can not be deserialized like {self.__class__.__name__}, ignoring')
                 else:
                     raise Exception(f'{value} can not be deserialized like {self.__class__.__name__}')
 
@@ -112,7 +116,7 @@ class RedisDateTime(RedisString):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
             check_types(self.value, datetime.datetime)
-            string_datetime = self.value.strftime('%Y.%m.%d-%H:%M:%S+%Z')
+            string_datetime = self.value.replace(tzinfo=pytz.UTC).strftime('%Y.%m.%d-%H:%M:%S+%Z')
             self.value = string_datetime
         return super().clean()
 
@@ -121,7 +125,7 @@ class RedisDateTime(RedisString):
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
             check_types(value, str)
-            value = datetime.datetime.strptime(value, '%Y.%m.%d-%H:%M:%S+%Z')
+            value = datetime.datetime.strptime(value, '%Y.%m.%d-%H:%M:%S+%Z').replace(tzinfo=pytz.UTC)
         else:
             value = None
         return value
@@ -149,9 +153,11 @@ class RedisForeignKey(RedisNumber):
                 if 'id' in self.value.keys():
                     self.value = self.value['id']
                 else:
-                    raise Exception(f"{self.value} has no key 'id', please provide serialized instance or dict like " + "{'id': 1, ...}")
+                    raise Exception(
+                        f"{self.value} has no key 'id', please provide serialized instance or dict like " + "{'id': 1, ...}")
             else:
-                raise Exception(f'{self.value} type is not dict, please provide serialized instance or dict like ' + "{'id': 1, ...}")
+                raise Exception(
+                    f'{self.value} type is not dict, please provide serialized instance or dict like ' + "{'id': 1, ...}")
         return self.value
 
     def clean(self):
@@ -330,6 +336,7 @@ class RedisDate(RedisString):
             value = None
         return value
 
+
 # class RedisDjangoForeignKey(RedisNumber):
 #
 #     def __init__(self, django_model=None, **kwargs):
@@ -408,7 +415,8 @@ class RedisRoot:
         if type(prefix) == str:
             self.prefix = prefix
         else:
-            print(f'{datetime.datetime.now()} - Prefix {prefix} is type of {type(prefix)}, allowed only str, using default prefix "redis_test"')
+            print(
+                f'{datetime.datetime.now()} - Prefix {prefix} is type of {type(prefix)}, allowed only str, using default prefix "redis_test"')
             self.prefix = 'redis_test'
         self.connection_pool = self._get_connection_pool(connection_pool)
         self.async_db_requests_limit = async_db_requests_limit
@@ -440,7 +448,8 @@ class RedisRoot:
                     'cache_conf': cache_conf
                 }
         if django_models_to_cache:
-            print(f"{datetime.datetime.now()} - {', '.join([str(model) for model in django_models_to_cache.keys()])} will be cached now...")
+            print(
+                f"{datetime.datetime.now()} - {', '.join([str(model) for model in django_models_to_cache.keys()])} will be cached now...")
         return django_models_to_cache
 
     def get_cache_conf(self, django_model):
@@ -448,7 +457,17 @@ class RedisRoot:
             cache_conf = self.registered_django_models[django_model]['cache_conf']
             return cache_conf
         else:
-            raise Exception(f'{django_model} is not registered')
+            cache_conf = {
+                'enabled': False,
+                'ttl': 60 * 5,
+                'save_related_models': True,
+                'cache_func': default_cache_func,
+                'exclude_fields': [],
+                'filter_by': {},
+                'write_to_django': False,
+                'delete': False,
+            }
+            return cache_conf
 
     def django_fields_to_redis_fields(self, django_model, save_related_models, exclude_fields):
         redis_fields = {}
@@ -513,7 +532,7 @@ class RedisRoot:
             )
 
             redis_field_params = self.django_field_params_to_redis_field_params(django_field,
-                                                                           save_related_models, exclude_fields)
+                                                                                save_related_models, exclude_fields)
             redis_field = redis_field_class(**redis_field_params)
         return redis_field
 
@@ -569,7 +588,8 @@ class RedisRoot:
         if django_model.__name__ in registered_models_names:
             existing_redis_model_index = registered_models_names.index(django_model.__name__)
             existing_redis_model = self.registered_models[existing_redis_model_index]
-            new_redis_model = self.update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields)
+            new_redis_model = self.update_redis_model_from_redis_fields(django_model, existing_redis_model,
+                                                                        redis_fields)
         else:
             new_redis_model = self.create_redis_model_from_redis_fields(django_model, redis_fields)
         return new_redis_model
@@ -577,7 +597,6 @@ class RedisRoot:
     def check_cache(self):
         django_models_to_cache = self._get_django_models_to_cache()
         for django_model, cache_conf in django_models_to_cache.items():
-
             print(f'{datetime.datetime.now()} - '
                   f'Start caching {django_model}'
                   f'\n')
@@ -593,7 +612,6 @@ class RedisRoot:
                   f'Cached {django_model} successfully'
                   f'\n\n\n')
 
-
     def fast_get_keys_values(self, string):
         keys = list(self.redis_instance.keys(string))
         values = self.redis_instance.mget(keys)
@@ -605,7 +623,8 @@ class RedisRoot:
             connection_pool.connection_kwargs['decode_responses'] = True
             self.connection_pool = connection_pool
         else:
-            print(f'{datetime.datetime.now()} - {self.__class__.__name__}: No connection_pool provided, trying default config...')
+            print(
+                f'{datetime.datetime.now()} - {self.__class__.__name__}: No connection_pool provided, trying default config...')
             default_host = 'localhost'
             default_port = 6379
             default_db = 0
@@ -740,7 +759,8 @@ class RedisRoot:
                 field_instance = getattr(model, field_name)
         except BaseException as ex:
             if self.ignore_deserialization_errors:
-                print(f'{datetime.datetime.now()} - {model.__name__} has no field {field_name}, ignoring deserialization')
+                print(
+                    f'{datetime.datetime.now()} - {model.__name__} has no field {field_name}, ignoring deserialization')
                 field_instance = field_name
             else:
                 raise Exception(f'{model.__name__} has no field {field_name}')
@@ -752,7 +772,8 @@ class RedisRoot:
             pass
         except BaseException as ex:
             if self.ignore_deserialization_errors:
-                print(f'{datetime.datetime.now()} - {raw_value} can not be deserialized like {field_instance.__class__.__name__}, ignoring')
+                print(
+                    f'{datetime.datetime.now()} - {raw_value} can not be deserialized like {field_instance.__class__.__name__}, ignoring')
                 value = raw_value
             else:
                 raise Exception(f'{raw_value} can not be deserialized like {field_instance.__class__.__name__}')
@@ -855,7 +876,8 @@ class RedisRoot:
         filter_field_name, filter_type = filter_param, 'exact'
         if '__' in filter_param:
             filter_param_split = filter_param.split('__')
-            if filter_param_split[-1] in ['exact', 'iexact', 'contains', 'icontains', 'in', 'gt', 'gte', 'lt', 'lte', 'startswith', 'istartswith', 'endswith', 'iendswith', 'range']:
+            if filter_param_split[-1] in ['exact', 'iexact', 'contains', 'icontains', 'in', 'gt', 'gte', 'lt', 'lte',
+                                          'startswith', 'istartswith', 'endswith', 'iendswith', 'range']:
                 fields_to_filter = filter_param_split[:-1]
                 filter_type = filter_param_split[-1]
             else:
@@ -872,6 +894,9 @@ class RedisRoot:
                 raise Exception(f'KeyError: {ex}\n'
                                 f'Info: {field_to_filter}, {value}\n'
                                 f'Maybe: deep filtering is not included on this model')
+        if isinstance(value, datetime.datetime) and isinstance(filter_by, datetime.datetime):
+            value = value.replace(tzinfo=pytz.UTC)
+            filter_by = filter_by.replace(tzinfo=pytz.UTC)
         allowed = self._filter_value(value, filter_type, filter_by)
         return allowed
 
@@ -937,20 +962,13 @@ class RedisRoot:
             instances_with_allowed = self._check_fields_existence(redis_model, instances_with_allowed, filters)
         instances = self._get_instances_from_instances_with_allowed(instances_with_allowed)
         return instances
-    
-    def _django_model_to_redis_model(self, django_model):
-        if django_model in self.registered_django_models.keys():
-            redis_model = self.get_or_create_redis_model_from_django_model(django_model)
-            return redis_model
-        else:
-            raise Exception(f'Django redis_model {django_model} is not registered in redis cache')
 
     def get_by_redis_model(self, redis_model, return_dict=False, **filters):
         instances = self._get_all_redis_model_instances(redis_model, filters)
         return self._return_with_format(instances, return_dict)
 
     def get(self, django_model, return_dict=False, **filters):
-        redis_model = self._django_model_to_redis_model(django_model)
+        redis_model = self.get_or_create_redis_model_from_django_model(django_model)
         result = self.get_by_redis_model(redis_model, return_dict, **filters)
         return result
 
@@ -1004,8 +1022,9 @@ class RedisRoot:
             }
         return updated_data
 
-    def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None, **fields_to_update):
-        model = self._django_model_to_redis_model(django_model)
+    def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None,
+               **fields_to_update):
+        model = self.get_or_create_redis_model_from_django_model(django_model)
         model_name = model.__name__
         updated_datas = []
         if instances is None:
@@ -1037,7 +1056,7 @@ class RedisRoot:
         self.redis_instance.delete(key)
 
     def delete(self, django_model, instances=None):
-        model = self._django_model_to_redis_model(django_model)
+        model = self.get_or_create_redis_model_from_django_model(django_model)
         model_name = model.__name__
         if instances is None:
             for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
@@ -1070,7 +1089,7 @@ class RedisRoot:
     #     return result
 
     def create(self, django_model, **params):
-        redis_model = self._django_model_to_redis_model(django_model)
+        redis_model = self.get_or_create_redis_model_from_django_model(django_model)
         redis_instance = redis_model(redis_root=self, **params).save()
         return redis_instance
 
@@ -1158,7 +1177,7 @@ class RedisModel:
                 except BaseException as ex:
                     raise Exception(f'{ex} ({name} -> {field_name})')
         return instance_key, cleaned_fields, deserialized_fields
-    
+
     def get_model_ttl(self):
         ttl = None
         meta = self.__model_data__['meta']
@@ -1217,4 +1236,3 @@ class RedisModel:
             return meta[field_name]
         else:
             raise Exception(f'{name} has no field {field_name}')
-
